@@ -28,15 +28,17 @@
 
 #include "glplp.h"
 
-#define ipm1                  _glp_ipm1
-#define ipm1_driver           _glp_ipm1_driver
+#define ipm1                  glp_ipm1
+#define ipm1_driver           glp_ipm1_driver
 
 extern int ipm1(MAT *A, double b[], double c[], double x[], double y[],
       double z[]);
 /* primal-dual interior point method for linear programming */
 
+#if 0
 extern int ipm1_driver(LP *lp, LPSOL *sol);
 /* driver for primal-dual interior point method */
+#endif
 
 #endif
 
