@@ -31,71 +31,71 @@
 #include "glplib.h"
 #include "glptext.h"
 
-#define addition              _glp_l_addition
-#define arith_expr            _glp_l_arith_expr
-#define array_decl            _glp_l_array_decl
-#define assign_stmt           _glp_l_assign_stmt
-#define build_form            _glp_l_build_form
-#define cmp_tuples            _glp_l_cmp_tuples
-#define comparison            _glp_l_comparison
-#define constant              _glp_l_constant
-#define copy_expr             _glp_l_copy_expr
-#define create_index          _glp_l_create_index
-#define create_prob           _glp_l_create_prob
-#define data_func             _glp_l_data_func
-#define delete_index          _glp_l_delete_index
-#define delete_prob           _glp_l_delete_prob
-#define designator            _glp_l_designator
-#define display_stmt          _glp_l_display_stmt
-#define enclose_expr          _glp_l_enclose_expr
-#define erase_expr            _glp_l_erase_expr
-#define erase_form            _glp_l_erase_form
-#define erase_spar            _glp_l_erase_spar
-#define eval_const            _glp_l_eval_const
-#define expand_spar           _glp_l_expand_spar
-#define expression            _glp_l_expression
-#define fatal                 _glp_l_fatal
-#define find_memb             _glp_l_find_memb
-#define find_mute             _glp_l_find_mute
-#define gener_lp              _glp_l_gener_lp
-#define gener_name            _glp_l_gener_name
-#define get_token             _glp_l_get_token
-#define index_memb            _glp_l_index_memb
-#define infix_expr            _glp_l_infix_expr
-#define initialize            _glp_l_initialize
-#define load_model            _glp_l_load_model
-#define logical_and           _glp_l_logical_and
-#define logical_not           _glp_l_logical_not
-#define logical_or            _glp_l_logical_or
-#define log_primary           _glp_l_log_primary
-#define log_secondary         _glp_l_log_secondary
-#define make_const            _glp_l_make_const
-#define make_expr             _glp_l_make_expr
-#define make_refer            _glp_l_make_refer
-#define multiplication        _glp_l_multiplication
-#define objective             _glp_l_objective
-#define outstr                _glp_l_outstr
-#define parse_model           _glp_l_parse_model
-#define pdb                   _glp_l_pdb
-#define primary               _glp_l_primary
-#define print_expr            _glp_l_print_expr
-#define print_spar            _glp_l_print_spar
-#define relation              _glp_l_relation
-#define secondary             _glp_l_secondary
-#define selection             _glp_l_selection
-#define set_decl              _glp_l_set_decl
-#define simple_expr           _glp_l_simple_expr
-#define stack_size            _glp_l_stack_size
-#define sum_func              _glp_l_sum_func
-#define summation             _glp_l_summation
-#define table_func            _glp_l_table_func
-#define terminate             _glp_l_terminate
-#define transpose             _glp_l_transpose
-#define unary_op              _glp_l_unary_op
-#define var_decl              _glp_l_var_decl
+#define addition              glp_lang_addition
+#define arith_expr            glp_lang_arith_expr
+#define array_decl            glp_lang_array_decl
+#define assign_stmt           glp_lang_assign_stmt
+#define build_form            glp_lang_build_form
+#define cmp_tuples            glp_lang_cmp_tuples
+#define comparison            glp_lang_comparison
+#define constant              glp_lang_constant
+#define copy_expr             glp_lang_copy_expr
+#define create_index          glp_lang_create_index
+#define create_prob           glp_lang_create_prob
+#define data_func             glp_lang_data_func
+#define delete_index          glp_lang_delete_index
+#define delete_prob           glp_lang_delete_prob
+#define designator            glp_lang_designator
+#define display_stmt          glp_lang_display_stmt
+#define enclose_expr          glp_lang_enclose_expr
+#define erase_expr            glp_lang_erase_expr
+#define erase_form            glp_lang_erase_form
+#define erase_spar            glp_lang_erase_spar
+#define eval_const            glp_lang_eval_const
+#define expand_spar           glp_lang_expand_spar
+#define expression            glp_lang_expression
+#define fatal                 glp_lang_fatal
+#define find_memb             glp_lang_find_memb
+#define find_mute             glp_lang_find_mute
+#define gener_lp              glp_lang_gener_lp
+#define gener_name            glp_lang_gener_name
+#define get_token             glp_lang_get_token
+#define index_memb            glp_lang_index_memb
+#define infix_expr            glp_lang_infix_expr
+#define initialize            glp_lang_initialize
+#define load_model            glp_lang_load_model
+#define logical_and           glp_lang_logical_and
+#define logical_not           glp_lang_logical_not
+#define logical_or            glp_lang_logical_or
+#define log_primary           glp_lang_log_primary
+#define log_secondary         glp_lang_log_secondary
+#define make_const            glp_lang_make_const
+#define make_expr             glp_lang_make_expr
+#define make_refer            glp_lang_make_refer
+#define multiplication        glp_lang_multiplication
+#define objective             glp_lang_objective
+#define outstr                glp_lang_outstr
+#define parse_model           glp_lang_parse_model
+#define pdb                   glp_lang_pdb
+#define primary               glp_lang_primary
+#define print_expr            glp_lang_print_expr
+#define print_spar            glp_lang_print_spar
+#define relation              glp_lang_relation
+#define secondary             glp_lang_secondary
+#define selection             glp_lang_selection
+#define set_decl              glp_lang_set_decl
+#define simple_expr           glp_lang_simple_expr
+#define stack_size            glp_lang_stack_size
+#define sum_func              glp_lang_sum_func
+#define summation             glp_lang_summation
+#define table_func            glp_lang_table_func
+#define terminate             glp_lang_terminate
+#define transpose             glp_lang_transpose
+#define unary_op              glp_lang_unary_op
+#define var_decl              glp_lang_var_decl
 
 #define MAX_NAME 31
-/* maximal length of symbolic name (not including '\0') */
+/* maximal length of symbolic name (except '\0') */
 
 #define MAX_DIM 6
 /* maximal dimension of sparse array */
