@@ -30,89 +30,105 @@
 #include "glpspm.h"
 #include "glpstr.h"
 
-#define lpx_create_prob       _glp_lpx_create_prob
-#define lpx_realloc_prob      _glp_lpx_realloc_prob
-#define lpx_add_rows          _glp_lpx_add_rows
-#define lpx_add_cols          _glp_lpx_add_cols
-#define lpx_check_name        _glp_lpx_check_name
-#define lpx_set_prob_name     _glp_lpx_set_prob_name
-#define lpx_set_row_name      _glp_lpx_set_row_name
-#define lpx_set_col_name      _glp_lpx_set_col_name
-#define lpx_set_row_bnds      _glp_lpx_set_row_bnds
-#define lpx_set_col_bnds      _glp_lpx_set_col_bnds
-#define lpx_set_class         _glp_lpx_set_class
-#define lpx_set_col_kind      _glp_lpx_set_col_kind
-#define lpx_set_obj_dir       _glp_lpx_set_obj_dir
-#define lpx_set_obj_c0        _glp_lpx_set_obj_c0
-#define lpx_set_row_coef      _glp_lpx_set_row_coef
-#define lpx_set_col_coef      _glp_lpx_set_col_coef
-#define lpx_set_row_stat      _glp_lpx_set_row_stat
-#define lpx_set_col_stat      _glp_lpx_set_col_stat
-#define lpx_load_mat          _glp_lpx_load_mat
-#define lpx_load_mat3         _glp_lpx_load_mat3
-#define lpx_set_mat_row       _glp_lpx_set_mat_row
-#define lpx_set_mat_col       _glp_lpx_set_mat_col
-#define lpx_unmark_all        _glp_lpx_unmark_all
-#define lpx_mark_row          _glp_lpx_mark_row
-#define lpx_mark_col          _glp_lpx_mark_col
-#define lpx_clear_mat         _glp_lpx_clear_mat
-#define lpx_del_items         _glp_lpx_del_items
-#define lpx_delete_prob       _glp_lpx_delete_prob
+#define lpx_create_prob       glp_lpx_create_prob
+#define lpx_realloc_prob      glp_lpx_realloc_prob
+#define lpx_add_rows          glp_lpx_add_rows
+#define lpx_add_cols          glp_lpx_add_cols
+#define lpx_check_name        glp_lpx_check_name
+#define lpx_set_prob_name     glp_lpx_set_prob_name
+#define lpx_set_row_name      glp_lpx_set_row_name
+#define lpx_set_col_name      glp_lpx_set_col_name
+#define lpx_set_row_bnds      glp_lpx_set_row_bnds
+#define lpx_set_col_bnds      glp_lpx_set_col_bnds
+#define lpx_set_class         glp_lpx_set_class
+#define lpx_set_col_kind      glp_lpx_set_col_kind
+#define lpx_set_obj_name      glp_lpx_set_obj_name
+#define lpx_set_obj_dir       glp_lpx_set_obj_dir
+#define lpx_set_obj_c0        glp_lpx_set_obj_c0
+#define lpx_set_row_coef      glp_lpx_set_row_coef
+#define lpx_set_col_coef      glp_lpx_set_col_coef
+#define lpx_set_row_stat      glp_lpx_set_row_stat
+#define lpx_set_col_stat      glp_lpx_set_col_stat
+#define lpx_load_mat          glp_lpx_load_mat
+#define lpx_load_mat3         glp_lpx_load_mat3
+#define lpx_set_mat_row       glp_lpx_set_mat_row
+#define lpx_set_mat_col       glp_lpx_set_mat_col
+#define lpx_unmark_all        glp_lpx_unmark_all
+#define lpx_mark_row          glp_lpx_mark_row
+#define lpx_mark_col          glp_lpx_mark_col
+#define lpx_clear_mat         glp_lpx_clear_mat
+#define lpx_del_items         glp_lpx_del_items
+#define lpx_delete_prob       glp_lpx_delete_prob
 
-#define lpx_get_num_rows      _glp_lpx_get_num_rows
-#define lpx_get_num_cols      _glp_lpx_get_num_cols
-#define lpx_get_num_int       _glp_lpx_get_num_int
-#define lpx_get_num_bin       _glp_lpx_get_num_bin
-#define lpx_get_num_nz        _glp_lpx_get_num_nz
-#define lpx_get_prob_name     _glp_lpx_get_prob_name
-#define lpx_get_row_name      _glp_lpx_get_row_name
-#define lpx_get_col_name      _glp_lpx_get_col_name
-#define lpx_get_row_bnds      _glp_lpx_get_row_bnds
-#define lpx_get_col_bnds      _glp_lpx_get_col_bnds
-#define lpx_get_class         _glp_lpx_get_class
-#define lpx_get_col_kind      _glp_lpx_get_col_kind
-#define lpx_get_obj_dir       _glp_lpx_get_obj_dir
-#define lpx_get_obj_c0        _glp_lpx_get_obj_c0
-#define lpx_get_row_coef      _glp_lpx_get_row_coef
-#define lpx_get_col_coef      _glp_lpx_get_col_coef
-#define lpx_get_mat_row       _glp_lpx_get_mat_row
-#define lpx_get_mat_col       _glp_lpx_get_mat_col
-#define lpx_get_status        _glp_lpx_get_status
-#define lpx_get_prim_stat     _glp_lpx_get_prim_stat
-#define lpx_get_dual_stat     _glp_lpx_get_dual_stat
-#define lpx_get_row_info      _glp_lpx_get_row_info
-#define lpx_get_col_info      _glp_lpx_get_col_info
-#define lpx_get_obj_val       _glp_lpx_get_obj_val
-#define lpx_get_mip_stat      _glp_lpx_get_mip_stat
-#define lpx_get_mip_row       _glp_lpx_get_mip_row
-#define lpx_get_mip_col       _glp_lpx_get_mip_col
-#define lpx_get_mip_obj       _glp_lpx_get_mip_obj
+#define lpx_get_num_rows      glp_lpx_get_num_rows
+#define lpx_get_num_cols      glp_lpx_get_num_cols
+#define lpx_get_num_int       glp_lpx_get_num_int
+#define lpx_get_num_bin       glp_lpx_get_num_bin
+#define lpx_get_num_nz        glp_lpx_get_num_nz
+#define lpx_get_prob_name     glp_lpx_get_prob_name
+#define lpx_get_row_name      glp_lpx_get_row_name
+#define lpx_get_col_name      glp_lpx_get_col_name
+#define lpx_get_row_bnds      glp_lpx_get_row_bnds
+#define lpx_get_col_bnds      glp_lpx_get_col_bnds
+#define lpx_get_class         glp_lpx_get_class
+#define lpx_get_col_kind      glp_lpx_get_col_kind
+#define lpx_get_obj_name      glp_lpx_get_obj_name
+#define lpx_get_obj_dir       glp_lpx_get_obj_dir
+#define lpx_get_obj_c0        glp_lpx_get_obj_c0
+#define lpx_get_row_coef      glp_lpx_get_row_coef
+#define lpx_get_col_coef      glp_lpx_get_col_coef
+#define lpx_get_mat_row       glp_lpx_get_mat_row
+#define lpx_get_mat_col       glp_lpx_get_mat_col
+#define lpx_get_row_mark      glp_lpx_get_row_mark
+#define lpx_get_col_mark      glp_lpx_get_col_mark
+#define lpx_get_status        glp_lpx_get_status
+#define lpx_get_prim_stat     glp_lpx_get_prim_stat
+#define lpx_get_dual_stat     glp_lpx_get_dual_stat
+#define lpx_get_row_info      glp_lpx_get_row_info
+#define lpx_get_col_info      glp_lpx_get_col_info
+#define lpx_get_obj_val       glp_lpx_get_obj_val
+#define lpx_get_ips_stat      glp_lpx_get_ips_stat
+#define lpx_get_ips_row       glp_lpx_get_ips_row
+#define lpx_get_ips_col       glp_lpx_get_ips_col
+#define lpx_get_ips_obj       glp_lpx_get_ips_obj
+#define lpx_get_mip_stat      glp_lpx_get_mip_stat
+#define lpx_get_mip_row       glp_lpx_get_mip_row
+#define lpx_get_mip_col       glp_lpx_get_mip_col
+#define lpx_get_mip_obj       glp_lpx_get_mip_obj
 
-#define lpx_reset_parms       _glp_lpx_reset_parms
-#define lpx_set_int_parm      _glp_lpx_set_int_parm
-#define lpx_get_int_parm      _glp_lpx_get_int_parm
-#define lpx_set_real_parm     _glp_lpx_set_real_parm
-#define lpx_get_real_parm     _glp_lpx_get_real_parm
+#define lpx_reset_parms       glp_lpx_reset_parms
+#define lpx_set_int_parm      glp_lpx_set_int_parm
+#define lpx_get_int_parm      glp_lpx_get_int_parm
+#define lpx_set_real_parm     glp_lpx_set_real_parm
+#define lpx_get_real_parm     glp_lpx_get_real_parm
 
-#define lpx_scale_prob        _glp_lpx_scale_prob
-#define lpx_unscale_prob      _glp_lpx_unscale_prob
+#define lpx_scale_prob        glp_lpx_scale_prob
+#define lpx_unscale_prob      glp_lpx_unscale_prob
 
-#define lpx_std_basis         _glp_lpx_std_basis
-#define lpx_adv_basis         _glp_lpx_adv_basis
+#define lpx_std_basis         glp_lpx_std_basis
+#define lpx_adv_basis         glp_lpx_adv_basis
 
-#define lpx_warm_up           _glp_lpx_warm_up
-#define lpx_prim_opt          _glp_lpx_prim_opt
-#define lpx_prim_art          _glp_lpx_prim_art
-#define lpx_dual_opt          _glp_lpx_dual_opt
-#define lpx_simplex           _glp_lpx_simplex
-#define lpx_integer           _glp_lpx_integer
+#define lpx_warm_up           glp_lpx_warm_up
+#define lpx_prim_opt          glp_lpx_prim_opt
+#define lpx_prim_art          glp_lpx_prim_art
+#define lpx_dual_opt          glp_lpx_dual_opt
+#define lpx_simplex           glp_lpx_simplex
+#define lpx_interior          glp_lpx_interior
+#define lpx_integer           glp_lpx_integer
 
-#define lpx_eval_tab_row      _glp_lpx_eval_tab_row
-#define lpx_eval_tab_col      _glp_lpx_eval_tab_col
+#define lpx_eval_tab_row      glp_lpx_eval_tab_row
+#define lpx_eval_tab_col      glp_lpx_eval_tab_col
+#define lpx_transform_row     glp_lpx_transform_row
+#define lpx_transform_col     glp_lpx_transform_col
+#define lpx_prim_ratio_test   glp_lpx_prim_ratio_test
+#define lpx_dual_ratio_test   glp_lpx_dual_ratio_test
 
-#define lpx_read_mps          _glp_lpx_read_mps
-#define lpx_print_sol         _glp_lpx_print_sol
-#define lpx_print_mip         _glp_lpx_print_mip
+#define lpx_read_lpm          glp_lpx_read_lpm
+#define lpx_read_mps          glp_lpx_read_mps
+#define lpx_write_mps         glp_lpx_write_mps
+#define lpx_print_sol         glp_lpx_print_sol
+#define lpx_print_ips         glp_lpx_print_ips
+#define lpx_print_mip         glp_lpx_print_mip
 
 /*----------------------------------------------------------------------
 -- The structure LPX defines LP/MIP problem object, which includes the
@@ -256,7 +272,7 @@
 --
 --    cR" = inv(R) * cR    (obj. coefficients at auxiliary variables)
 --
---    cS" = S * cR         (obj. coefficients at structural variables)
+--    cS" = S * cS         (obj. coefficients at structural variables)
 --
 --    xR" = R * xR         (values of auxiliary variables)
 --    lR" = R * lR         (lower bounds of auxiliary variables)
@@ -294,12 +310,14 @@ struct LPX
       /* working buffer used to return character strings */
       /*--------------------------------------------------------------*/
       /* LP problem data */
-      int class;
+      STR *prob;
+      /* symbolic name of the LP problem object */
+      int clss;
       /* problem class: */
 #define LPX_LP          100   /* linear programming (LP) */
 #define LPX_MIP         101   /* mixed integer programming (MIP) */
       STR **name; /* STR *name[1+m+n]; */
-      /* name[0] is a name of the LP problem object;
+      /* name[0] is not used;
          name[k], 1 <= k <= m+n, is a name of the variable x[k] */
       int *typx; /* int typx[1+m_max+n_max]; */
       /* typx[0] is not used;
@@ -329,6 +347,8 @@ struct LPX
          mark[k], 1 <= k <= m+n, is a marker of the variable x[k];
          these markers are used to mark rows and columns for various
          purposes */
+      STR *obj;
+      /* symbolic name of the objective function */
       int dir;
       /* optimization direction (sense of the objective function): */
 #define LPX_MIN         120   /* minimization */
@@ -341,7 +361,7 @@ struct LPX
       SPM *A; /* SPM A[1:m,1:n]; */
       /* constraint matrix (has m rows and n columns) */
       /*--------------------------------------------------------------*/
-      /* current basis and basic solution components */
+      /* basic solution segment */
       int b_stat;
       /* status of the current basis: */
 #define LPX_B_UNDEF     130   /* current basis is undefined */
@@ -398,20 +418,34 @@ struct LPX
          cbar[j], 1 <= j <= n, is a reduced cost of non-basic variable
          xN[j] */
       /*--------------------------------------------------------------*/
+      /* interior point solution segment */
+      int t_stat;
+      /* status of the interior point solution: */
+#define LPX_T_UNDEF     150   /* solution is undefined */
+#define LPX_T_OPT       151   /* solution is optimal */
+      double *pv; /* double pv[1+m_max+n_max]; */
+      /* pv[0] is not used;
+         pv[k], 1 <= k <= m+n, is a primal value of the variable x[k];
+         if t_stat = LPX_T_UNDEF, this array may be unallocated */
+      double *dv; /* double dv[1+m_max+n_max]; */
+      /* dv[0] is not used;
+         dv[k], 1 <= k <= m+n, is a dual value of the variable x[k];
+         if t_stat = LPX_T_UNDEF, this array may be unallocated */
+      /*--------------------------------------------------------------*/
       /* mixed integer programming (MIP) segment */
       int *kind; /* int kind[1+n_max]; */
       /* kind[0] is not used;
          kind[j], 1 <= j <= n, specifies the kind of the j-th structural
          variable: */
-#define LPX_CV          150   /* continuous variable */
-#define LPX_IV          151   /* integer variable */
+#define LPX_CV          160   /* continuous variable */
+#define LPX_IV          161   /* integer variable */
       int i_stat;
       /* status of the integer solution: */
-#define LPX_I_UNDEF     160   /* integer status is undefined */
-#define LPX_I_OPT       161   /* solution is integer optimal */
-#define LPX_I_FEAS      162   /* solution is integer feasible */
-#define LPX_I_NOFEAS    163   /* no integer solution exists */
-      double *mipx; /* double mipx[1+m+n]; */
+#define LPX_I_UNDEF     170   /* integer status is undefined */
+#define LPX_I_OPT       171   /* solution is integer optimal */
+#define LPX_I_FEAS      172   /* solution is integer feasible */
+#define LPX_I_NOFEAS    173   /* no integer solution exists */
+      double *mipx; /* double mipx[1+m_max+n_max]; */
       /* mipx[0] is not used;
          mipx[k], 1 <= k <= m+n, is an (unscaled!) value of the variable
          x[k] for integer optimal or integer feasible solution */
@@ -517,51 +551,84 @@ struct LPX
       /* relative tolerance used to check if the value of the objective
          function is not better than in the best known integer feasible
          solution */
+      int mps_info; /* lpx_write_mps */
+      /* if this flag is set, the routine lpx_write_mps outputs several
+         comment cards that contains some information about the problem;
+         otherwise the routine outputs no comment cards */
+      int mps_obj; /* lpx_write_mps */
+      /* this parameter tells the routine lpx_write_mps how to output
+         the objective function row:
+         0 - never output objective function row
+         1 - always output objective function row
+         2 - output objective function row if and only if the problem
+             has no free rows */
+      int mps_orig; /* lpx_write_mps */
+      /* if this flag is set, the routine lpx_write_mps uses original
+         row and column symbolic names; otherwise the routine generates
+         plain names using ordinal numbers of rows and columns */
+      int mps_wide; /* lpx_write_mps */
+      /* if this flag is set, the routine lpx_write_mps uses all data
+         fields; otherwise the routine keeps fields 5 and 6 empty */
+      int mps_free; /* lpx_write_mps */
+      /* if this flag is set, the routine lpx_write_mps omits column
+         and vector names everytime if possible (free style); otherwise
+         the routine never omits these names (pedantic style) */
+      int mps_skip; /* lpx_write_mps */
+      /* if this flag is set, the routine lpx_write_mps skips empty
+         columns (i.e. which has no constraint coefficients); otherwise
+         the routine outputs all columns */
 };
 
 /* status codes reported by the routine lpx_get_status: */
-#define LPX_OPT         170   /* optimal */
-#define LPX_FEAS        171   /* feasible */
-#define LPX_INFEAS      172   /* infeasible */
-#define LPX_NOFEAS      173   /* no feasible */
-#define LPX_UNBND       174   /* unbounded */
-#define LPX_UNDEF       175   /* undefined */
+#define LPX_OPT         180   /* optimal */
+#define LPX_FEAS        181   /* feasible */
+#define LPX_INFEAS      182   /* infeasible */
+#define LPX_NOFEAS      183   /* no feasible */
+#define LPX_UNBND       184   /* unbounded */
+#define LPX_UNDEF       185   /* undefined */
 
 /* exit codes returned by the simplex-based solver routines: */
-#define LPX_E_OK        180   /* success */
-#define LPX_E_EMPTY     181   /* empty problem */
-#define LPX_E_BADB      182   /* invalid initial basis */
-#define LPX_E_INFEAS    183   /* infeasible initial solution */
-#define LPX_E_FAULT     184   /* unable to start the search */
-#define LPX_E_OBJLL     185   /* objective lower limit reached */
-#define LPX_E_OBJUL     186   /* objective upper limit reached */
-#define LPX_E_ITLIM     187   /* iterations limit exhausted */
-#define LPX_E_TMLIM     188   /* time limit exhausted */
-#define LPX_E_NOFEAS    189   /* no feasible solution */
-#define LPX_E_INSTAB    190   /* numerical instability */
-#define LPX_E_SING      191   /* problems with basis matrix */
+#define LPX_E_OK        200   /* success */
+#define LPX_E_EMPTY     201   /* empty problem */
+#define LPX_E_BADB      202   /* invalid initial basis */
+#define LPX_E_INFEAS    203   /* infeasible initial solution */
+#define LPX_E_FAULT     204   /* unable to start the search */
+#define LPX_E_OBJLL     205   /* objective lower limit reached */
+#define LPX_E_OBJUL     206   /* objective upper limit reached */
+#define LPX_E_ITLIM     207   /* iterations limit exhausted */
+#define LPX_E_TMLIM     208   /* time limit exhausted */
+#define LPX_E_NOFEAS    209   /* no feasible solution */
+#define LPX_E_INSTAB    210   /* numerical instability */
+#define LPX_E_SING      211   /* problems with basis matrix */
+#define LPX_E_NOCONV    212   /* no convergence (interior) */
 
 /* control parameter identifiers */
-#define LPX_K_MSGLEV    200   /* lp->msg_lev */
-#define LPX_K_SCALE     201   /* lp->scale */
-#define LPX_K_DUAL      202   /* lp->dual */
-#define LPX_K_PRICE     203   /* lp->price */
-#define LPX_K_RELAX     204   /* lp->relax */
-#define LPX_K_TOLBND    205   /* lp->tol_bnd */
-#define LPX_K_TOLDJ     206   /* lp->tol_dj */
-#define LPX_K_TOLPIV    207   /* lp->tol_piv */
-#define LPX_K_ROUND     208   /* lp->round */
-#define LPX_K_OBJLL     209   /* lp->obj_ll */
-#define LPX_K_OBJUL     210   /* lp->obj_ul */
-#define LPX_K_ITLIM     211   /* lp->it_lim */
-#define LPX_K_ITCNT     212   /* lp->it_cnt */
-#define LPX_K_TMLIM     213   /* lp->tm_lim */
-#define LPX_K_OUTFRQ    214   /* lp->out_frq */
-#define LPX_K_OUTDLY    215   /* lp->out_dly */
-#define LPX_K_BRANCH    216   /* lp->branch */
-#define LPX_K_BTRACK    217   /* lp->btrack */
-#define LPX_K_TOLINT    218   /* lp->tol_int */
-#define LPX_K_TOLOBJ    219   /* lp->tol_obj */
+#define LPX_K_MSGLEV    300   /* lp->msg_lev */
+#define LPX_K_SCALE     301   /* lp->scale */
+#define LPX_K_DUAL      302   /* lp->dual */
+#define LPX_K_PRICE     303   /* lp->price */
+#define LPX_K_RELAX     304   /* lp->relax */
+#define LPX_K_TOLBND    305   /* lp->tol_bnd */
+#define LPX_K_TOLDJ     306   /* lp->tol_dj */
+#define LPX_K_TOLPIV    307   /* lp->tol_piv */
+#define LPX_K_ROUND     308   /* lp->round */
+#define LPX_K_OBJLL     309   /* lp->obj_ll */
+#define LPX_K_OBJUL     310   /* lp->obj_ul */
+#define LPX_K_ITLIM     311   /* lp->it_lim */
+#define LPX_K_ITCNT     312   /* lp->it_cnt */
+#define LPX_K_TMLIM     313   /* lp->tm_lim */
+#define LPX_K_OUTFRQ    314   /* lp->out_frq */
+#define LPX_K_OUTDLY    315   /* lp->out_dly */
+#define LPX_K_BRANCH    316   /* lp->branch */
+#define LPX_K_BTRACK    317   /* lp->btrack */
+#define LPX_K_TOLINT    318   /* lp->tol_int */
+#define LPX_K_TOLOBJ    319   /* lp->tol_obj */
+#define LPX_K_MPSINFO   320   /* lp->mps_info */
+#define LPX_K_MPSOBJ    321   /* lp->mps_obj */
+#define LPX_K_MPSORIG   322   /* lp->mps_orig */
+#define LPX_K_MPSWIDE   323   /* lp->mps_wide */
+#define LPX_K_MPSFREE   324   /* lp->mps_free */
+#define LPX_K_MPSSKIP   325   /* lp->mps_skip */
 
 /* problem creating and modifying routines ---------------------------*/
 
@@ -595,12 +662,15 @@ void lpx_set_row_bnds(LPX *lp, int i, int typx, double lb, double ub);
 void lpx_set_col_bnds(LPX *lp, int j, int typx, double lb, double ub);
 /* set (change) column bounds */
 
-void lpx_set_class(LPX *lp, int class);
+void lpx_set_class(LPX *lp, int clss);
 /* set (change) problem class */
 
 void lpx_set_col_kind(LPX *lp, int j, int kind);
 /* set (change) column kind */
 
+void lpx_set_obj_name(LPX *lp, char *name);
+/* assign (change) objective function name */
+
 void lpx_set_obj_dir(LPX *lp, int dir);
 /* set (change) optimization direction */
 
@@ -690,6 +760,9 @@ int lpx_get_class(LPX *lp);
 int lpx_get_col_kind(LPX *lp, int j);
 /* query column kind */
 
+char *lpx_get_obj_name(LPX *lp);
+/* obtain objective function name */
+
 int lpx_get_obj_dir(LPX *lp);
 /* determine optimization direction */
 
@@ -708,6 +781,12 @@ int lpx_get_mat_row(LPX *lp, int i, int ndx[], double val[]);
 int lpx_get_mat_col(LPX *lp, int j, int ndx[], double val[]);
 /* get column of the constraint matrix */
 
+int lpx_get_row_mark(LPX *lp, int i);
+/* determine row mark */
+
+int lpx_get_col_mark(LPX *lp, int j);
+/* determine column mark */
+
 int lpx_get_status(LPX *lp);
 /* query basic solution status */
 
@@ -728,6 +807,18 @@ void lpx_get_col_info(LPX *lp, int j, int *tagx, double *vx, double *dx)
 double lpx_get_obj_val(LPX *lp);
 /* obtain value of the objective function */
 
+int lpx_get_ips_stat(LPX *lp);
+/* query status of interior point solution */
+
+void lpx_get_ips_row(LPX *lp, int i, double *vx, double *dx);
+/* obtain row interior point solution */
+
+void lpx_get_ips_col(LPX *lp, int j, double *vx, double *dx);
+/* obtain column interior point solution */
+
+double lpx_get_ips_obj(LPX *lp);
+/* obtain interior point value of the obj. function */
+
 int lpx_get_mip_stat(LPX *lp);
 /* query status of MIP solution */
 
@@ -773,7 +864,7 @@ void lpx_std_basis(LPX *lp);
 void lpx_adv_basis(LPX *lp);
 /* build advanced initial basis */
 
-/* simplex-based solver routines -------------------------------------*/
+/* solver routines ---------------------------------------------------*/
 
 int lpx_warm_up(LPX *lp);
 /* "warm up" the initial basis */
@@ -790,6 +881,9 @@ int lpx_dual_opt(LPX *lp);
 int lpx_simplex(LPX *lp);
 /* easy-to-use driver to the simplex method */
 
+int lpx_interior(LPX *lp);
+/* easy-to-use driver to the interior point method */
+
 int lpx_integer(LPX *lp);
 /* easy-to-use driver to the branch-and-bound method */
 
@@ -801,14 +895,37 @@ int lpx_eval_tab_row(LPX *lp, int k, int ndx[], double val[]);
 int lpx_eval_tab_col(LPX *lp, int k, int ndx[], double val[]);
 /* compute column of the simplex table */
 
+int lpx_transform_row(LPX *lp, int len, int ndx[], double val[]);
+/* transform explicitly specified row */
+
+int lpx_transform_col(LPX *lp, int len, int ndx[], double val[]);
+/* transform explicitly specified column */
+
+int lpx_prim_ratio_test(LPX *lp, int len, int ndx[], double val[],
+      int how, double tol);
+/* perform primal ratio test */
+
+int lpx_dual_ratio_test(LPX *lp, int len, int ndx[], double val[],
+      int how, double tol);
+/* perform dual ratio test */
+
 /* additional utility routines ---------------------------------------*/
 
+LPX *lpx_read_lpm(char *infile, char *outfile);
+/* read LP/MIP model written in GLPK/L */
+
 LPX *lpx_read_mps(char *fname);
 /* read in problem data using MPS format */
 
+int lpx_write_mps(LPX *lp, char *fname);
+/* write problem data using MPS format */
+
 int lpx_print_sol(LPX *lp, char *fname);
 /* write LP problem solution in printable format */
 
+int lpx_print_ips(LPX *lp, char *fname);
+/* write interior point solution in printable format */
+
 int lpx_print_mip(LPX *lp, char *fname);
 /* write MIP problem solution in printable format */
 
