@@ -28,9 +28,9 @@
 
 #include "glplp.h"
 
-#define load_mps              _glp_load_mps
-#define free_mps              _glp_free_mps
-#define mps_to_lp             _glp_mps_to_lp
+#define load_mps              glp_load_mps
+#define free_mps              glp_free_mps
+#define mps_to_lp             glp_mps_to_lp
 
 typedef struct MPS MPS;
 typedef struct MPSROW MPSROW;
