@@ -28,17 +28,17 @@
 
 #include "glplib.h"
 
-#define str2int               _glp_str2int
-#define str2dbl               _glp_str2dbl
-#define strspx                _glp_strspx
-#define strtrim               _glp_strtrim
-#define clear_str             _glp_clear_str
-#define compare_str           _glp_compare_str
-#define create_str            _glp_create_str
-#define create_str_pool       _glp_create_str_pool
-#define delete_str            _glp_delete_str
-#define get_str               _glp_get_str
-#define set_str               _glp_set_str
+#define str2int               glp_str2int
+#define str2dbl               glp_str2dbl
+#define strspx                glp_strspx
+#define strtrim               glp_strtrim
+#define clear_str             glp_clear_str
+#define compare_str           glp_compare_str
+#define create_str            glp_create_str
+#define create_str_pool       glp_create_str_pool
+#define delete_str            glp_delete_str
+#define get_str               glp_get_str
+#define set_str               glp_set_str
 
 extern int str2int(char *str, int *val);
 /* convert character string to value of integer type */
