@@ -1,4 +1,4 @@
-/* glpsol.c */
+/* glpsol.c (stand-alone LP/MIP solver) */
 
 /*----------------------------------------------------------------------
 -- Copyright (C) 2000, 2001, 2002 Andrew Makhorin <mao@mai2.rcnet.ru>,
@@ -30,12 +30,13 @@
 
 /*----------------------------------------------------------------------
 -- This program is a stand-alone LP/MIP solver. For pure LP problems
--- either the revised simplex method or the primal dual interior-point
--- method can be used. For MIP problems the branch-and-bound procedure
--- based on the revised simplex method is used.
+-- either the simplex method or the primal-dual interior point method
+-- can be used. For MIP problems the branch-and-bound procedure based
+-- on the simplex method is used.
 ----------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0.8";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.2";
+/* the version string */
 
 static char *in_fname = NULL;
 /* name of the input text file */
@@ -49,20 +50,23 @@ static int check = 0;
 /* if this flag is set, only input data checking is required */
 
 static char *fn_gener = NULL;
-/* name of the output text file, to which the routine glp_read_lpm()
-   should output generated LP/MIP problem in plain text format; NULL
-   means no output */
+/* name of the output text file, to which generated LP/MIP problem
+   should be written in plain text format; NULL means no output */
+
+static char *fn_write = NULL;
+/* name of the output text file, to which LP/MIP problem should be
+   written using MPS format; NULL means no output */
 
 static int obj_dir = 0;
 /* optimization direction flag:
-    0  - not specified
-   '-' - minimization
-   '+' - maximization */
+   0       - not specified
+   LPX_MIN - minimization
+   LPX_MAX - maximization */
 
 static int method = 'S';
-/* the method which should be used for solving a problem:
-   'S' - revised simplex method
-   'I' - interior point method */
+/* the method which should be used for solving the problem:
+   'S' - simplex method
+   'T' - interior point method */
 
 static char *out_fname = NULL;
 /* name of the output text file to which the final solution should be
@@ -72,10 +76,15 @@ static int scale = 1;
 /* if this flag is set, the solver performs automatic scaling the
    problem before solving; otherwise scaling is not used */
 
-static int steep = 1;
-/* if this flag is set, the solver uses the steepest edge pricing (for
-   both primal and dual simplex) proposed by Goldfarb & Reid; otherwise
-   the solver uses the standard "textbook" pricing */
+static int basis = 1;
+/* this parameter specifies initial basis option:
+   0 - use standard initial basis
+   1 - use advanced initial basis */
+
+static int price = 1;
+/* this parameter specifies pricing option:
+   0 - use textbook pricing
+   1 - use steepest edge pricing */
 
 static int relax = 1;
 /* if this flag is set, the solver uses two-pass ratio test (for both
@@ -86,25 +95,25 @@ static int nomip = 0;
 /* if this flag is set, the solver considers all integer variables as
    continuous (this allows solving MIP problem as pure LP) */
 
-static int branch = BB_DRTOM;
+static int branch = 2;
 /* this parameter specifies what branching technique should be used by
    the solver:
-   BB_FIRST - branch on the first integer variable
-   BB_LAST  - branch on the last integer variable
-   BB_DRTOM - branch using heuristic by Driebeek and Tomlin */
+   0 - branch on the first integer variable
+   1 - branch on the last integer variable
+   2 - branch using heuristic by Driebeek and Tomlin */
 
-static int btrack = BB_BESTP;
+static int btrack = 2;
 /* this parameter specifies what backtracking technique should be used
    by the solver:
-   BB_FIFO  - backtrack using FIFO heuristic
-   BB_LIFO  - backtrack using LIFO heuristic
-   BB_BESTP - backtrack using the best projection heuristic */
+   0 - backtrack using depth first search
+   1 - backtrack using breadth first search
+   2 - backtrack using the best projection heuristic */
 
 /*----------------------------------------------------------------------
 -- display_help - display help.
 --
--- This routine displays help information about the program as it is
--- required by the GNU Coding Standards. */
+-- This routine displays help information about the program as required
+-- by the GNU Coding Standards. */
 
 static void display_help(char *my_name)
 {     print("Usage: %s [options...] filename", my_name);
@@ -117,18 +126,20 @@ static void display_help(char *my_name)
       print("                     language");
       print("   --check           do not solve the problem, check input"
          " data only");
-      print("   --gener filename  send generated LP/MIP problem to file"
-         "name using");
-      print("                     plain text format (has meaning for --"
-         "lpm only)");
+      print("   --gener filename  write generated LP/MIP problem to fil"
+         "ename in");
+      print("                     plain text format (has sense for --lp"
+         "m only)");
+      print("   --write filename  write LP/MIP problem to filename in M"
+         "PS format");
       print("   --min             minimize the objective function");
       print("   --max             maximize the objective function");
       print("   --simplex         use simplex method (default)");
       print("   --interior        use interior point method (for pure L"
          "P only)");
       print("   -o filename, --output filename");
-      print("                     send solution to filename using print"
-         "able format");
+      print("                     write solution to filename in plain t"
+         "ext format");
       print("   --scale           scale the problem (default)");
       print("   --noscale         do not scale the problem");
       print("   -h, --help        display this help information and exi"
@@ -136,6 +147,9 @@ static void display_help(char *my_name)
       print("   -v, --version     display program version and exit");
       print("");
       print("Options specific to simplex method:");
+      print("   --std             use standard initial basis");
+      print("   --adv             use advanced initial basis (default)")
+         ;
       print("   --steep           use steepest edge technique (default)"
          );
       print("   --nosteep         use standard \"textbook\" pricing");
@@ -154,16 +168,17 @@ static void display_help(char *my_name)
       print("   --drtom           branch using heuristic by Driebeck an"
          "d Tomlin");
       print("                     (default)");
-      print("   --fifo            backtrack using FIFO heuristic");
-      print("   --lifo            backtrack using LIFO heuristic");
+      print("   --dfs             backtrack using depth first search");
+      print("   --bfs             backtrack using breadth first search")
+         ;
       print("   --bestp           backtrack using the best projection h"
          "euristic");
       print("                     (default)");
       print("");
-      print("See the official GNU webpage dedicated to GLPK at");
-      print("<http://www.gnu.org/software/glpk/glpk.html>");
+      print("See GLPK webpage at <http://www.gnu.org/software/glpk/glpk"
+         ".html>");
       print("");
-      print("Please, report bugs to <bug-glpk@gnu.org>");
+      print("Report bugs to <bug-glpk@gnu.org>");
       exit(EXIT_SUCCESS);
       /* no return */
 }
@@ -171,8 +186,8 @@ static void display_help(char *my_name)
 /*----------------------------------------------------------------------
 -- display_version - display version.
 --
--- This routine displays version information for the program as it is
--- required by the GNU Coding Standards. */
+-- This routine displays version information for the program as required
+-- by the GNU Coding Standards. */
 
 static void display_version(void)
 {     print("%s", version);
@@ -189,7 +204,7 @@ static void display_version(void)
 /*----------------------------------------------------------------------
 -- process_cmdline - process command line parameters.
 --
--- This routine processes parameters specified in command line. */
+-- This routine processes parameters specified in the command line. */
 
 #define p(str) (strcmp(argv[k], str) == 0)
 
@@ -205,23 +220,31 @@ static void process_cmdline(int argc, char *argv[])
          else if (p("--gener"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
-            {  print("No gener file name specified");
+            {  print("No output gener filename specified");
                exit(EXIT_FAILURE);
             }
             fn_gener = argv[k];
          }
+         else if (p("--write"))
+         {  k++;
+            if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
+            {  print("No output MPS filename specified");
+               exit(EXIT_FAILURE);
+            }
+            fn_write = argv[k];
+         }
          else if (p("--min"))
-            obj_dir = '-';
+            obj_dir = LPX_MIN;
          else if (p("--max"))
-            obj_dir = '+';
+            obj_dir = LPX_MAX;
          else if (p("--simplex"))
             method = 'S';
          else if (p("--interior"))
-            method = 'I';
+            method = 'T';
          else if (p("-o") || p("--output"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
-            {  print("No output file name specified");
+            {  print("No output solution filename specified");
                exit(EXIT_FAILURE);
             }
             out_fname = argv[k];
@@ -234,10 +257,14 @@ static void process_cmdline(int argc, char *argv[])
             display_help(argv[0]);
          else if (p("-v") || p("--version"))
             display_version();
+         else if (p("--std"))
+            basis = 0;
+         else if (p("--adv"))
+            basis = 1;
          else if (p("--steep"))
-            steep = 1;
+            price = 1;
          else if (p("--nosteep"))
-            steep = 0;
+            price = 0;
          else if (p("--relax"))
             relax = 1;
          else if (p("--norelax"))
@@ -245,17 +272,17 @@ static void process_cmdline(int argc, char *argv[])
          else if (p("--nomip"))
             nomip = 1;
          else if (p("--first"))
-            branch = BB_FIRST;
+            branch = 0;
          else if (p("--last"))
-            branch = BB_LAST;
+            branch = 1;
          else if (p("--drtom"))
-            branch = BB_DRTOM;
-         else if (p("--fifo"))
-            btrack = BB_FIFO;
+            branch = 2;
+         else if (p("--dfs"))
+            btrack = 0;
          else if (p("--lifo"))
-            btrack = BB_LIFO;
+            btrack = 1;
          else if (p("--bestp"))
-            btrack = BB_BESTP;
+            btrack = 2;
          else if (argv[k][0] == '-' ||
                  (argv[k][0] == '-' && argv[k][1] == '-'))
          {  print("Invalid option `%s'; try %s --help",
@@ -280,86 +307,118 @@ static void process_cmdline(int argc, char *argv[])
 -- solving process. */
 
 int main(int argc, char *argv[])
-{     LPI *lp;
+{     LPX *lp;
+      int ret;
       double start;
       /* process command line parameters */
       process_cmdline(argc, argv);
-      /* read LP problem data from the input file */
+      /* read problem data from the input file */
       if (in_fname == NULL)
       {  print("No input file name specified; try %s --help", argv[0]);
          exit(EXIT_FAILURE);
       }
       switch (format)
       {  case 'M':
-            lp = glp_read_mps1(in_fname);
+            lp = lpx_read_mps(in_fname);
             if (lp == NULL)
             {  print("MPS file processing error");
                exit(EXIT_FAILURE);
             }
             break;
          case 'L':
-            lp = glp_read_lpm1(in_fname, fn_gener);
+            lp = lpx_read_lpm(in_fname, fn_gener);
             if (lp == NULL)
-            {  print("Model description processing error");
+            {  print("Model processing error");
+               exit(EXIT_FAILURE);
+            }
+            if (lpx_get_num_rows(lp) == 0)
+            {  print("Problem has no rows");
+               exit(EXIT_FAILURE);
+            }
+            if (lpx_get_num_cols(lp) == 0)
+            {  print("Problem has no columns");
                exit(EXIT_FAILURE);
             }
             break;
          default:
             insist(format != format);
       }
-      /* change optimization direction */
-      if (obj_dir != 0) glp_set_obj_sense(lp, obj_dir);
+      /* write problem data in MPS format (if required) */
+      if (fn_write != NULL)
+      {  ret = lpx_write_mps(lp, fn_write);
+         if (ret != 0)
+         {  print("Unable to write MPS file");
+            exit(EXIT_FAILURE);
+         }
+      }
       /* if only data check is required, skip computations */
       if (check) goto skip;
-      /* solve LP/MIP problem */
-      start = watch();
+      /* change optimization direction (if required) */
+      if (obj_dir != 0) lpx_set_obj_dir(lp, obj_dir);
+      /* scale the problem data (if required) */
+      if (scale) lpx_scale_prob(lp);
+      /* build an advanced initial basis (if required) */
+      if (method == 'S' && basis) lpx_adv_basis(lp);
+      /* set some control parameters, which might be changed in the
+         command line */
+      lpx_set_int_parm(lp, LPX_K_PRICE, price);
+      if (!relax) lpx_set_real_parm(lp, LPX_K_RELAX, 0.0);
+      lpx_set_int_parm(lp, LPX_K_BRANCH, branch);
+      lpx_set_int_parm(lp, LPX_K_BTRACK, btrack);
+      /* solve the problem */
+      start = utime();
       switch (method)
       {  case 'S':
-            if (nomip || glp_get_num_int(lp) == 0)
-            {  struct spx parm;
-               glp_init_spx(&parm);
-               parm.scale = scale;
-               parm.price = steep;
-               parm.relax = relax;
-               glp_simplex(lp, &parm);
-            }
+            if (nomip || lpx_get_class(lp) == LPX_LP)
+               lpx_simplex(lp);
             else
-            {  struct bnb parm;
-               glp_init_bnb(&parm);
-               parm.branch = branch;
-               parm.btrack = btrack;
-               parm.scale = scale;
-               parm.steep = steep;
-               parm.relax = relax;
-               glp_integer(lp, &parm);
+            {  method = 'I';
+               lpx_simplex(lp);
+               lpx_integer(lp);
             }
             break;
-         case 'I':
-            if (glp_get_num_int(lp) > 0 && !nomip)
+         case 'T':
+            if (nomip || lpx_get_class(lp) == LPX_LP)
+               lpx_interior(lp);
+            else
             {  print("Interior point solver is not able to solve MIP pr"
                   "oblem; use --simplex");
                exit(EXIT_FAILURE);
             }
-            glp_interior(lp);
             break;
          default:
             insist(method != method);
       }
-      /* display statistics */
-      print("Time used:   %.1f secs", watch() - start);
+      /* display statistics (FYI: one megabyte is 1,000,000 bytes) */
+      print("Time used:   %.1f secs", utime() - start);
       print("Memory used: %.1fM (%d bytes)",
-         (double)get_env_ptr()->mem_tpeak / (double)1000000,
-         get_env_ptr()->mem_tpeak);
-      /* write problem solution found by the solver */
-      if (out_fname != NULL && glp_print_soln(lp, out_fname) != 0)
-      {  print("Unable to write problem solution");
-         exit(EXIT_FAILURE);
+         (double)lib_env_ptr()->mem_tpeak / (double)1000000,
+         lib_env_ptr()->mem_tpeak);
+      /* write problem solution found by the solver (if required) */
+      if (out_fname != NULL)
+      {  switch (method)
+         {  case 'S':
+               ret = lpx_print_sol(lp, out_fname);
+               break;
+            case 'I':
+               ret = lpx_print_mip(lp, out_fname);
+               break;
+            case 'T':
+               ret = lpx_print_ips(lp, out_fname);
+               break;
+            default:
+               insist(method != method);
+         }
+         if (ret != 0)
+         {  print("Unable to write problem solution");
+            exit(EXIT_FAILURE);
+         }
       }
 skip: /* delete the problem object */
-      glp_delete_prob(lp);
+      lpx_delete_prob(lp);
 #if 0
       print("%d %d",
-         get_env_ptr()->mem_total, get_env_ptr()->mem_count);
+         lib_env_ptr()->mem_total, lib_env_ptr()->mem_count);
 #endif
       /* exit to the control program */
       return 0;
