@@ -246,7 +246,7 @@ static void initialize(LP *mip, LPSOL *sol)
       /* allocate auxiliary working array */
       work = ucalloc(1+m+n, sizeof(int));
       /* reset timers */
-      start = watch();
+      start = utime();
       t_last = -1.0;
       /* create the root problem */
       node = get_atom(bb->node_pool);
@@ -311,7 +311,7 @@ static void display(void)
          print("+%6d: mip = %17.9e; lp = %17.9e (%d; %d)",
             bb->rsm->iter, s * bb->best, s * bb->root->objval,
             bb->count, bb->total);
-      t_last = watch();
+      t_last = utime();
       return;
 }
 
@@ -360,9 +360,9 @@ static int dual_monit(void)
 {     int ret = 0;
       double spent;
       /* determine the spent amount of time */
-      spent = watch() - start;
+      spent = utime() - start;
       /* display visual information (once per three seconds) */
-      if (t_last < 0.0 || watch() - t_last >= 2.9) display();
+      if (t_last < 0.0 || utime() - t_last >= 2.9) display();
       /* if the current value of the objective function is not better
          than for the best integer feasible solution, further search is
          useless and may be terminated */
@@ -451,9 +451,9 @@ static int primal_monit(void)
 {     int ret = 0;
       double spent;
       /* determine the spent amount of time */
-      spent = watch() - start;
+      spent = utime() - start;
       /* display visual information (once per three seconds) */
-      if (t_last < 0.0 || watch() - t_last >= 2.9)
+      if (t_last < 0.0 || utime() - t_last >= 2.9)
       {  int i, j, k, defect;
          double objval, infsum;
          /* compute current values of basic variables */
@@ -490,7 +490,7 @@ static int primal_monit(void)
          print("%c%6d:   objval = %17.9e   infsum = %17.9e (%d)",
             phase == 1 ? ' ' : '*', bb->rsm->iter, objval, infsum,
             defect);
-         t_last = watch();
+         t_last = utime();
       }
       /* check if the iterations limit has been exhausted */
       if (cp->it_lim >= 0 && bb->rsm->iter >= cp->it_lim)
@@ -887,7 +887,7 @@ static int solve_problem(BBNODE *node, int warm)
          problem */
       if (ret == 2)
       {  print("Numerical instability; recovering...");
-         t_last = watch();
+         t_last = utime();
          /* although the current (dual infeasible) basis may be used as
             initial basis, the practice shows that it's better to start
             again from the optimal basis of the parent problem */
@@ -913,7 +913,7 @@ static int solve_problem(BBNODE *node, int warm)
          once again */
       while (ret == 2)
       {  print("Numerical instability (again); recovering...");
-         t_last = watch();
+         t_last = utime();
          /* reinvert the current basis matrix (this usually helps to
             improve accuracy of the representation) */
          if (invert_b(bb->rsm))
@@ -1545,7 +1545,7 @@ done: /* reflect the spent resources in the parameter block */
       }
       cp->it_cnt = bb->rsm->iter;
       if (cp->tm_lim >= 0.0)
-      {  cp->tm_lim -= (watch() - start);
+      {  cp->tm_lim -= (utime() - start);
          if (cp->tm_lim < 0.0) cp->tm_lim = 0.0;
       }
       /* terminate branch-and-bound environment */
