@@ -226,6 +226,7 @@ void delete_lpsol(LPSOL *sol)
       return;
 }
 
+#if 0
 /*----------------------------------------------------------------------
 -- extract_prob - extract LP problem data from LPI object.
 --
@@ -275,6 +276,7 @@ LP *extract_prob(void *lpi)
          fault("extract_prob: constraint matrix has multiplets");
       return lp;
 }
+#endif
 
 /*----------------------------------------------------------------------
 -- prepro_lp - perform preprocessing LP/MIP problem.
