@@ -56,14 +56,15 @@ LPX *lpx_create_prob(void)
       lp->m = lp->n = 0;
       lp->pool = create_str_pool();
       lp->buf = ucalloc(255+1, sizeof(char));
-      lp->class = LPX_LP;
+      lp->prob = NULL;
+      lp->clss = LPX_LP;
       lp->name = ucalloc(1+m_max+n_max, sizeof(STR *));
-      lp->name[0] = NULL;
       lp->typx = ucalloc(1+m_max+n_max, sizeof(int));
       lp->lb = ucalloc(1+m_max+n_max, sizeof(double));
       lp->ub = ucalloc(1+m_max+n_max, sizeof(double));
       lp->rs = ucalloc(1+m_max+n_max, sizeof(double));
       lp->mark = ucalloc(1+m_max+n_max, sizeof(int));
+      lp->obj = NULL;
       lp->dir = LPX_MIN;
       lp->coef = ucalloc(1+m_max+n_max, sizeof(double));
       lp->coef[0] = 0.0;
@@ -78,6 +79,9 @@ LPX *lpx_create_prob(void)
       lp->bbar = ucalloc(1+m_max, sizeof(double));
       lp->pi = ucalloc(1+m_max, sizeof(double));
       lp->cbar = ucalloc(1+n_max, sizeof(double));
+      lp->t_stat = LPX_T_UNDEF;
+      lp->pv = NULL;
+      lp->dv = NULL;
       lp->kind = NULL;
       lp->i_stat = LPX_I_UNDEF;
       lp->mipx = NULL;
@@ -127,7 +131,11 @@ void lpx_realloc_prob(LPX *lp, int m_max, int n_max)
       reallocate(double, lp->bbar, 1+m_max, 1+m);
       reallocate(double, lp->pi, 1+m_max, 1+m);
       reallocate(double, lp->cbar, 1+n_max, 1+n);
-      if (lp->class == LPX_MIP)
+      if (lp->pv != NULL)
+         reallocate(double, lp->pv, 1+m_max+n_max, 1+m+n);
+      if (lp->dv != NULL)
+         reallocate(double, lp->dv, 1+m_max+n_max, 1+m+n);
+      if (lp->clss == LPX_MIP)
       {  reallocate(int, lp->kind, 1+n_max, 1+n);
          reallocate(double, lp->mipx, 1+m_max+n_max, 1+m+n);
       }
@@ -218,6 +226,7 @@ void lpx_add_rows(LPX *lp, int nrs)
       lp->b_stat = LPX_B_UNDEF;
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -243,7 +252,7 @@ void lpx_add_rows(LPX *lp, int nrs)
 void lpx_add_cols(LPX *lp, int ncs)
 {     int m = lp->m;
       int n = lp->n;
-      int class = lp->class;
+      int clss = lp->clss;
       STR **name = lp->name;
       int *typx = lp->typx;
       double *lb = lp->lb;
@@ -288,7 +297,7 @@ void lpx_add_cols(LPX *lp, int ncs)
          /* the new column is non-basic */
          tagx[j] = LPX_NS;
          /* the new column is continuous */
-         if (class == LPX_MIP) kind[j-m] = LPX_CV;
+         if (clss == LPX_MIP) kind[j-m] = LPX_CV;
       }
       /* set new number of columns */
       lp->n = n_new;
@@ -298,6 +307,7 @@ void lpx_add_cols(LPX *lp, int ncs)
       lp->b_stat = LPX_B_UNDEF;
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -348,16 +358,16 @@ int lpx_check_name(char *name)
 
 void lpx_set_prob_name(LPX *lp, char *name)
 {     if (name == NULL)
-      {  if (lp->name[0] != NULL)
-         {  delete_str(lp->name[0]);
-            lp->name[0] = NULL;
+      {  if (lp->prob != NULL)
+         {  delete_str(lp->prob);
+            lp->prob = NULL;
          }
       }
       else
       {  if (lpx_check_name(name))
             fault("lpx_set_prob_name: invalid problem name");
-         if (lp->name[0] == NULL) lp->name[0] = create_str(lp->pool);
-         set_str(lp->name[0], name);
+         if (lp->prob == NULL) lp->prob = create_str(lp->pool);
+         set_str(lp->prob, name);
       }
       return;
 }
@@ -497,6 +507,7 @@ void lpx_set_row_bnds(LPX *lp, int i, int typx, double lb, double ub)
       /* invalidate the basic solution */
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -516,7 +527,7 @@ void lpx_set_row_bnds(LPX *lp, int i, int typx, double lb, double ub)
 -- j-th column.
 --
 -- Parameters typx, lb, and ub specify respectively the type, the lower
--- bound, and the upper bound, which should be set for the i-th row:
+-- bound, and the upper bound, which should be set for the j-th column:
 --
 --     Type          Bounds            Note
 --    -------------------------------------------
@@ -568,6 +579,7 @@ void lpx_set_col_bnds(LPX *lp, int j, int typx, double lb, double ub)
       /* invalidate the basic solution */
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -578,27 +590,27 @@ void lpx_set_col_bnds(LPX *lp, int j, int typx, double lb, double ub)
 -- *Synopsis*
 --
 -- #include "glplpx.h"
--- void lpx_set_class(LPX *lp, int class);
+-- void lpx_set_class(LPX *lp, int clss);
 --
 -- *Description*
 --
 -- The routine lpx_set_class sets (changes) the class of the problem
--- object as specified by the parameter class:
+-- object as specified by the parameter clss:
 --
 -- LPX_LP  - pure linear programming (LP) problem;
 -- LPX_MIP - mixed integer programming (MIP) problem. */
 
-void lpx_set_class(LPX *lp, int class)
-{     switch (class)
+void lpx_set_class(LPX *lp, int clss)
+{     switch (clss)
       {  case LPX_LP:
-            if (lp->class == LPX_MIP)
+            if (lp->clss == LPX_MIP)
             {  /* deallocate MIP data segment */
                ufree(lp->kind), lp->kind = NULL;
                ufree(lp->mipx), lp->mipx = NULL;
             }
             break;
          case LPX_MIP:
-            if (lp->class == LPX_LP)
+            if (lp->clss == LPX_LP)
             {  /* allocate and initialize MIP data segment */
                int j;
                lp->kind = ucalloc(1+lp->n_max, sizeof(int));
@@ -609,11 +621,10 @@ void lpx_set_class(LPX *lp, int class)
             }
             break;
          default:
-            fault("lpx_set_class: class = %d; invalid parameter",
-               class);
+            fault("lpx_set_class: clss = %d; invalid parameter", clss);
       }
       /* set (change) problem class */
-      lp->class = class;
+      lp->clss = clss;
       return;
 }
 
@@ -634,7 +645,7 @@ void lpx_set_class(LPX *lp, int class)
 -- LPX_IV - integer variable. */
 
 void lpx_set_col_kind(LPX *lp, int j, int kind)
-{     if (lp->class != LPX_MIP)
+{     if (lp->clss != LPX_MIP)
          fault("lpx_set_col_kind: error -- not a MIP problem");
       if (!(1 <= j && j <= lp->n))
          fault("lpx_set_col_kind: j = %d; column number out of range",
@@ -646,6 +657,38 @@ void lpx_set_col_kind(LPX *lp, int j, int kind)
       return;
 }
 
+/*----------------------------------------------------------------------
+-- lpx_set_obj_name - assign (change) objective function name.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- void lpx_set_obj_name(LPX *lp, char *name);
+--
+-- *Description*
+--
+-- The routine lpx_set_obj_name assigns a given symbolic name to the
+-- objective function of the specified problem object.
+--
+-- If the parameter name is NULL, the routine just erases an existing
+-- name of the objective function. */
+
+void lpx_set_obj_name(LPX *lp, char *name)
+{     if (name == NULL)
+      {  if (lp->obj != NULL)
+         {  delete_str(lp->obj);
+            lp->obj = NULL;
+         }
+      }
+      else
+      {  if (lpx_check_name(name))
+            fault("lpx_set_obj_name: invalid objective function name");
+         if (lp->obj == NULL) lp->obj = create_str(lp->pool);
+         set_str(lp->obj, name);
+      }
+      return;
+}
+
 /*----------------------------------------------------------------------
 -- lpx_set_obj_dir - set (change) optimization direction.
 --
@@ -670,6 +713,7 @@ void lpx_set_obj_dir(LPX *lp, int dir)
       /* invalidate the basic solution */
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -713,6 +757,7 @@ void lpx_set_row_coef(LPX *lp, int i, double coef)
       /* invalidate the basic solution */
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -739,6 +784,7 @@ void lpx_set_col_coef(LPX *lp, int j, double coef)
       /* invalidate the basic solution */
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -886,18 +932,6 @@ void lpx_set_col_stat(LPX *lp, int j, int stat)
 -- "rewind" the file in order to begin enumerating again from the first
 -- element. */
 
-#if 0
-void lpx_load_mat(LPX *lp,
-      void *info, double (*mat)(void *info, int *i, int *j))
-{     spm_load_data(lp->A, info, mat);
-      /* invalidate the factorization and the basic solution */
-      lp->b_stat = LPX_B_UNDEF;
-      lp->p_stat = LPX_P_UNDEF;
-      lp->d_stat = LPX_D_UNDEF;
-      lp->i_stat = LPX_I_UNDEF;
-      return;
-}
-#else
 struct mat_info
 {     /* transit information passed to the routine mat */
       LPX *lp;
@@ -938,10 +972,10 @@ void lpx_load_mat(LPX *lp,
       lp->b_stat = LPX_B_UNDEF;
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
-#endif
 
 /*----------------------------------------------------------------------
 -- lpx_load_mat3 - load constraint matrix.
@@ -1058,6 +1092,7 @@ void lpx_set_mat_row(LPX *lp, int i, int len, int ndx[], double val[])
       /* invalidate the basic solution */
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -1100,6 +1135,7 @@ void lpx_set_mat_col(LPX *lp, int j, int len, int ndx[], double val[])
       /* invalidate the basic solution */
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -1214,6 +1250,7 @@ skip: /* clear marked rows of the constraint matrix */
       /* invalidate the basic solution */
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -1234,7 +1271,7 @@ skip: /* clear marked rows of the constraint matrix */
 void lpx_del_items(LPX *lp)
 {     int m = lp->m;
       int n = lp->n;
-      int class = lp->class;
+      int clss = lp->clss;
       STR **name = lp->name;
       int *typx = lp->typx;
       double *lb = lp->lb;
@@ -1263,7 +1300,7 @@ void lpx_del_items(LPX *lp)
             rs[k_new] = rs[k];
             coef[k_new] = coef[k];
             tagx[k_new] = tagx[k];
-            if (class == LPX_MIP && k > m) kind[n_new] = kind[k-m];
+            if (clss == LPX_MIP && k > m) kind[n_new] = kind[k-m];
          }
       }
       /* delete marked rows from the constraint matrix */
@@ -1279,6 +1316,7 @@ void lpx_del_items(LPX *lp)
       lp->b_stat = LPX_B_UNDEF;
       lp->p_stat = LPX_P_UNDEF;
       lp->d_stat = LPX_D_UNDEF;
+      lp->t_stat = LPX_T_UNDEF;
       lp->i_stat = LPX_I_UNDEF;
       return;
 }
@@ -1314,7 +1352,9 @@ void lpx_delete_prob(LPX *lp)
       ufree(lp->bbar);
       ufree(lp->pi);
       ufree(lp->cbar);
-      if (lp->class == LPX_MIP)
+      if (lp->pv != NULL) ufree(lp->pv);
+      if (lp->dv != NULL) ufree(lp->dv);
+      if (lp->clss == LPX_MIP)
       {  ufree(lp->kind);
          ufree(lp->mipx);
       }
