@@ -80,7 +80,7 @@ int lpx_get_num_cols(LPX *lp)
 
 int lpx_get_num_int(LPX *lp)
 {     int count = 0, j;
-      if (lp->class != LPX_MIP)
+      if (lp->clss != LPX_MIP)
          fault("lpx_get_num_int: error -- not a MIP problem");
       for (j = 1; j <= lp->n; j++)
          if (lp->kind[j] == LPX_IV) count++;
@@ -104,7 +104,7 @@ int lpx_get_num_int(LPX *lp)
 int lpx_get_num_bin(LPX *lp)
 {     int count = 0, j, k;
       double trick = 1e-12;
-      if (lp->class != LPX_MIP)
+      if (lp->clss != LPX_MIP)
          fault("lpx_get_num_bin: error -- not a MIP problem");
       for (j = 1; j <= lp->n; j++)
       {  if (lp->kind[j] == LPX_IV)
@@ -155,7 +155,7 @@ int lpx_get_num_nz(LPX *lp)
 
 char *lpx_get_prob_name(LPX *lp)
 {     return
-         lp->name[0] == NULL ? NULL : get_str(lp->buf, lp->name[0]);
+         lp->prob == NULL ? NULL : get_str(lp->buf, lp->prob);
 }
 
 /*----------------------------------------------------------------------
@@ -307,8 +307,8 @@ void lpx_get_col_bnds(LPX *lp, int j, int *typx, double *lb, double *ub)
 -- LPX_MIP - mixed integer programming (MIP) problem. */
 
 int lpx_get_class(LPX *lp)
-{     int class = lp->class;
-      return class;
+{     int clss = lp->clss;
+      return clss;
 }
 
 /*----------------------------------------------------------------------
@@ -328,7 +328,7 @@ int lpx_get_class(LPX *lp)
 -- LPX_IV - integer variable. */
 
 int lpx_get_col_kind(LPX *lp, int j)
-{     if (lp->class != LPX_MIP)
+{     if (lp->clss != LPX_MIP)
          fault("lpx_get_col_kind: error -- not a MIP problem");
       if (!(1 <= j && j <= lp->n))
          fault("lpx_get_col_kind: j = %d; column number out of range",
@@ -336,6 +336,26 @@ int lpx_get_col_kind(LPX *lp, int j)
       return lp->kind[j];
 }
 
+/*----------------------------------------------------------------------
+-- lpx_get_obj_name - obtain objective function name.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- char *lpx_get_obj_name(LPX *lp);
+--
+-- *Returns*
+--
+-- The routine lpx_get_obj_name returns a pointer to a static buffer
+-- that contains a symbolic name of the objective function. However,
+-- if the objective function has no assigned name, the routine returns
+-- NULL. */
+
+char *lpx_get_obj_name(LPX *lp)
+{     return
+         lp->obj == NULL ? NULL : get_str(lp->buf, lp->obj);
+}
+
 /*----------------------------------------------------------------------
 -- lpx_get_obj_dir - determine optimization direction.
 --
@@ -508,6 +528,45 @@ int lpx_get_mat_col(LPX *lp, int j, int ndx[], double val[])
       return len;
 }
 
+/*----------------------------------------------------------------------
+-- lpx_get_row_mark - determine row mark.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- int lpx_get_row_mark(LPX *lp, int i);
+--
+-- *Returns*
+--
+-- The routine lpx_get_row_mark returns an integer mark assigned to the
+-- i-th row by the routine lpx_mark_row. */
+
+int lpx_get_row_mark(LPX *lp, int i)
+{     if (!(1 <= i && i <= lp->m))
+         fault("lpx_get_row_mark: i = %d; row number out of range", i);
+      return lp->mark[i];
+}
+
+/*----------------------------------------------------------------------
+-- lpx_get_col_mark - determine column mark.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- int lpx_get_col_mark(LPX *lp, int j);
+--
+-- *Returns*
+--
+-- The routine lpx_get_col_mark returns an integer mark assigned to the
+-- j-th column by the routine lpx_mark_col. */
+
+int lpx_get_col_mark(LPX *lp, int j)
+{     if (!(1 <= j && j <= lp->n))
+         fault("lpx_get_col_mark: j = %d; column number out of range",
+            j);
+      return lp->mark[lp->m + j];
+}
+
 /*----------------------------------------------------------------------
 -- lpx_get_status - query basic solution status.
 --
@@ -850,6 +909,161 @@ double lpx_get_obj_val(LPX *lp)
       return sum;
 }
 
+/*----------------------------------------------------------------------
+-- lpx_get_ips_stat - query status of interior point solution.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- int lpx_get_ips_stat(LPX *lp);
+--
+-- *Returns*
+--
+-- The routine lpx_get_ips_stat reports the status of interior point
+-- solution obtained by the solver for an LP problem object, which the
+-- parameter lp points to:
+--
+-- LPX_T_UNDEF  - the interior point solution is undefined;
+-- LPX_T_OPT    - the interior point solution is optimal.
+--
+-- Note that additional status codes may appear in the future versions
+-- of this routine. */
+
+int lpx_get_ips_stat(LPX *lp)
+{     int t_stat = lp->t_stat;
+      return t_stat;
+}
+
+/*----------------------------------------------------------------------
+-- lpx_get_ips_row - obtain row interior point solution.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- void lpx_get_ips_row(LPX *lp, int i, double *vx, double *dx);
+--
+-- *Description*
+--
+-- The routine lpx_get_ips_row stores primal and dual interior point
+-- values of the i-th auxiliary variable (row) to locations, which the
+-- parameters vx and dx point to, respectively. If some of pointers vx
+-- or dx is NULL, the corresponding value is not stored. */
+
+void lpx_get_ips_row(LPX *lp, int i, double *vx, double *dx)
+{     double vx_i, dx_i;
+      if (!(1 <= i && i <= lp->m))
+         fault("lpx_get_ips_row: i = %d; row number out of range", i);
+      switch (lp->t_stat)
+      {  case LPX_T_UNDEF:
+            vx_i = dx_i = 0.0;
+            break;
+         case LPX_T_OPT:
+            /* obtain primal and dual values */
+            vx_i = lp->pv[i];
+            dx_i = lp->dv[i];
+#if 0
+            /* round them (if required) */
+            if (lp->round)
+            {  if (fabs(vx_i) <= 1e-8) vx_i = 0.0;
+               if (fabs(dx_i) <= 1e-8) dx_i = 0.0;
+            }
+#endif
+            /* and unscale these values */
+            vx_i /= lp->rs[i];
+            dx_i *= lp->rs[i];
+            break;
+         default:
+            insist(lp->t_stat != lp->t_stat);
+      }
+      if (vx != NULL) *vx = vx_i;
+      if (dx != NULL) *dx = dx_i;
+      return;
+}
+
+/*----------------------------------------------------------------------
+-- lpx_get_ips_col - obtain column interior point solution.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- void lpx_get_ips_col(LPX *lp, int j, double *vx, double *dx);
+--
+-- *Description*
+--
+-- The routine lpx_get_ips_col stores primal and dual interior point
+-- values of the j-th structural variable (column) to locations, which
+-- the parameters vx and dx point to, respectively. If some of pointers
+-- vx or dx is NULL, the corresponding value is not stored. */
+
+void lpx_get_ips_col(LPX *lp, int j, double *vx, double *dx)
+{     double vx_j, dx_j;
+      if (!(1 <= j && j <= lp->n))
+         fault("lpx_get_ips_col: j = %d; column number out of range",
+            j);
+      j += lp->m;
+      switch (lp->t_stat)
+      {  case LPX_T_UNDEF:
+            vx_j = dx_j = 0.0;
+            break;
+         case LPX_T_OPT:
+            /* obtain primal and dual values */
+            vx_j = lp->pv[j];
+            dx_j = lp->dv[j];
+#if 0
+            /* round them (if required) */
+            if (lp->round)
+            {  if (fabs(vx_j) <= 1e-8) vx_j = 0.0;
+               if (fabs(dx_j) <= 1e-8) dx_j = 0.0;
+            }
+#endif
+            /* and unscale these values */
+            vx_j *= lp->rs[j];
+            dx_j /= lp->rs[j];
+            break;
+         default:
+            insist(lp->t_stat != lp->t_stat);
+      }
+      if (vx != NULL) *vx = vx_j;
+      if (dx != NULL) *dx = dx_j;
+      return;
+}
+
+/*----------------------------------------------------------------------
+-- lpx_get_ips_obj - obtain interior point value of the obj. function.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- double lpx_get_ips_obj(LPX *lp);
+--
+-- *Returns*
+--
+-- The routine lpx_get_ips_obj returns an interior point value of the
+-- objective function. */
+
+double lpx_get_ips_obj(LPX *lp)
+{     int m = lp->m;
+      int n = lp->n;
+      int i, j;
+      double sum, coef, vx;
+      sum = lpx_get_obj_c0(lp);
+      for (i = 1; i <= m; i++)
+      {  coef = lpx_get_row_coef(lp, i);
+         if (coef != 0.0)
+         {  lpx_get_ips_row(lp, i, &vx, NULL);
+            sum += coef * vx;
+         }
+      }
+      for (j = 1; j <= n; j++)
+      {  coef = lpx_get_col_coef(lp, j);
+         if (coef != 0.0)
+         {  lpx_get_ips_col(lp, j, &vx, NULL);
+            sum += coef * vx;
+         }
+      }
+      return sum;
+}
+
 /*----------------------------------------------------------------------
 -- lpx_get_mip_stat - query status of MIP solution.
 --
@@ -878,7 +1092,7 @@ double lpx_get_obj_val(LPX *lp)
 --                by the solver). */
 
 int lpx_get_mip_stat(LPX *lp)
-{     if (lp->class != LPX_MIP)
+{     if (lp->clss != LPX_MIP)
          fault("lpx_get_mip_stat: error -- not a MIP problem");
       return lp->i_stat;
 }
@@ -898,7 +1112,7 @@ int lpx_get_mip_stat(LPX *lp)
 
 double lpx_get_mip_row(LPX *lp, int i)
 {     double vx;
-      if (lp->class != LPX_MIP)
+      if (lp->clss != LPX_MIP)
          fault("lpx_get_mip_row: error -- not a MIP problem");
       if (!(1 <= i && i <= lp->m))
          fault("lpx_get_mip_row: i = %d; row number out of range", i);
@@ -929,7 +1143,7 @@ double lpx_get_mip_row(LPX *lp, int i)
 
 double lpx_get_mip_col(LPX *lp, int j)
 {     double vx;
-      if (lp->class != LPX_MIP)
+      if (lp->clss != LPX_MIP)
          fault("lpx_get_mip_col: error -- not a MIP problem");
       if (!(1 <= j && j <= lp->n))
          fault("lpx_get_mip_col: j = %d; column number out of range",
@@ -964,7 +1178,7 @@ double lpx_get_mip_col(LPX *lp, int j)
 double lpx_get_mip_obj(LPX *lp)
 {     int i, j;
       double sum, coef;
-      if (lp->class != LPX_MIP)
+      if (lp->clss != LPX_MIP)
          fault("lpx_get_mip_obj: error -- not a MIP problem");
       sum = lpx_get_obj_c0(lp);
       for (i = 1; i <= lp->m; i++)
