@@ -41,29 +41,35 @@
 -- default values. */
 
 void lpx_reset_parms(LPX *lp)
-{     lp->msg_lev = 3;
-      lp->scale   = 3;
-      lp->sc_ord  = 0;
-      lp->sc_max  = 20;
-      lp->sc_eps  = 0.01;
-      lp->dual    = 0;
-      lp->price   = 1;
-      lp->relax   = 0.07;
-      lp->tol_bnd = 1e-7;
-      lp->tol_dj  = 1e-7;
-      lp->tol_piv = 1e-9;
-      lp->round   = 0;
-      lp->obj_ll  = -DBL_MAX;
-      lp->obj_ul  = +DBL_MAX;
-      lp->it_lim  = -1;
-      lp->it_cnt  = 0;
-      lp->tm_lim  = -1.0;
-      lp->out_frq = 200;
-      lp->out_dly = 0.0;
-      lp->branch  = 2;
-      lp->btrack  = 2;
-      lp->tol_int = 1e-6;
-      lp->tol_obj = 1e-7;
+{     lp->msg_lev  = 3;
+      lp->scale    = 3;
+      lp->sc_ord   = 0;
+      lp->sc_max   = 20;
+      lp->sc_eps   = 0.01;
+      lp->dual     = 0;
+      lp->price    = 1;
+      lp->relax    = 0.07;
+      lp->tol_bnd  = 1e-7;
+      lp->tol_dj   = 1e-7;
+      lp->tol_piv  = 1e-9;
+      lp->round    = 0;
+      lp->obj_ll   = -DBL_MAX;
+      lp->obj_ul   = +DBL_MAX;
+      lp->it_lim   = -1;
+      lp->it_cnt   = 0;
+      lp->tm_lim   = -1.0;
+      lp->out_frq  = 200;
+      lp->out_dly  = 0.0;
+      lp->branch   = 2;
+      lp->btrack   = 2;
+      lp->tol_int  = 1e-6;
+      lp->tol_obj  = 1e-7;
+      lp->mps_info = 1;
+      lp->mps_obj  = 2;
+      lp->mps_orig = 0;
+      lp->mps_wide = 1;
+      lp->mps_free = 0;
+      lp->mps_skip = 0;
       return;
 }
 
@@ -137,6 +143,42 @@ void lpx_set_int_parm(LPX *lp, int parm, int val)
                   val);
             lp->btrack = val;
             break;
+         case LPX_K_MPSINFO:
+            if (!(val == 0 || val == 1))
+               fault("lpx_set_int_parm: MPSINFO = %d; invalid value",
+                  val);
+            lp->mps_info = val;
+            break;
+         case LPX_K_MPSOBJ:
+            if (!(val == 0 || val == 1 || val == 2))
+               fault("lpx_set_int_parm: MPSOBJ = %d; invalid value",
+                  val);
+            lp->mps_obj = val;
+            break;
+         case LPX_K_MPSORIG:
+            if (!(val == 0 || val == 1))
+               fault("lpx_set_int_parm: MPSORIG = %d; invalid value",
+                  val);
+            lp->mps_orig = val;
+            break;
+         case LPX_K_MPSWIDE:
+            if (!(val == 0 || val == 1))
+               fault("lpx_set_int_parm: MPSWIDE = %d; invalid value",
+                  val);
+            lp->mps_wide = val;
+            break;
+         case LPX_K_MPSFREE:
+            if (!(val == 0 || val == 1))
+               fault("lpx_set_int_parm: MPSFREE = %d; invalid value",
+                  val);
+            lp->mps_free = val;
+            break;
+         case LPX_K_MPSSKIP:
+            if (!(val == 0 || val == 1))
+               fault("lpx_set_int_parm: MPSSKIP = %d; invalid value",
+                  val);
+            lp->mps_skip = val;
+            break;
          default:
             fault("lpx_set_int_parm: parm = %d; invalid parameter",
                parm);
@@ -161,35 +203,37 @@ int lpx_get_int_parm(LPX *lp, int parm)
 {     int val = 0;
       switch (parm)
       {  case LPX_K_MSGLEV:
-            val = lp->msg_lev;
-            break;
+            val = lp->msg_lev; break;
          case LPX_K_SCALE:
-            val = lp->scale;
-            break;
+            val = lp->scale; break;
          case LPX_K_DUAL:
-            val = lp->dual;
-            break;
+            val = lp->dual; break;
          case LPX_K_PRICE:
-            val = lp->price;
-            break;
+            val = lp->price; break;
          case LPX_K_ROUND:
-            val = lp->round;
-            break;
+            val = lp->round; break;
          case LPX_K_ITLIM:
-            val = lp->it_lim;
-            break;
+            val = lp->it_lim; break;
          case LPX_K_ITCNT:
-            val = lp->it_cnt;
-            break;
+            val = lp->it_cnt; break;
          case LPX_K_OUTFRQ:
-            val = lp->out_frq;
-            break;
+            val = lp->out_frq; break;
          case LPX_K_BRANCH:
-            val = lp->branch;
-            break;
+            val = lp->branch; break;
          case LPX_K_BTRACK:
-            val = lp->btrack;
-            break;
+            val = lp->btrack; break;
+         case LPX_K_MPSINFO:
+            val = lp->mps_info; break;
+         case LPX_K_MPSOBJ:
+            val = lp->mps_obj; break;
+         case LPX_K_MPSORIG:
+            val = lp->mps_orig; break;
+         case LPX_K_MPSWIDE:
+            val = lp->mps_wide; break;
+         case LPX_K_MPSFREE:
+            val = lp->mps_free; break;
+         case LPX_K_MPSSKIP:
+            val = lp->mps_skip; break;
          default:
             fault("lpx_get_int_parm: parm = %d; invalid parameter",
                parm);
