@@ -25,6 +25,7 @@
 
 #include <float.h>
 #include <math.h>
+#include <stddef.h>
 #include "glpspx.h"
 
 /*----------------------------------------------------------------------
@@ -99,10 +100,10 @@ double spx_eval_xn_j(LPX *lp, int j)
 void spx_eval_bbar(LPX *lp)
 {     int m = lp->m;
       int n = lp->n;
-      int *aa_ptr = lp->aa_ptr;
-      int *aa_len = lp->aa_len;
-      int *sv_ndx = lp->sv_ndx;
-      double *sv_val = lp->sv_val;
+      int *aa_ptr = lp->A->ptr;
+      int *aa_len = lp->A->len;
+      int *sv_ndx = lp->A->ndx;
+      double *sv_val = lp->A->val;
       int *indx = lp->indx;
       double *bbar = lp->bbar;
       int i, j, j_beg, j_end, j_ptr, k;
@@ -198,10 +199,10 @@ void spx_eval_cbar(LPX *lp)
 {     int m = lp->m;
       int n = lp->n;
       double *coef = lp->coef;
-      int *aa_ptr = lp->aa_ptr;
-      int *aa_len = lp->aa_len;
-      int *sv_ndx = lp->sv_ndx;
-      double *sv_val = lp->sv_val;
+      int *aa_ptr = lp->A->ptr;
+      int *aa_len = lp->A->len;
+      int *sv_ndx = lp->A->ndx;
+      double *sv_val = lp->A->val;
       int *indx = lp->indx;
       double *pi = lp->pi;
       double *cbar = lp->cbar;
@@ -295,10 +296,10 @@ double spx_eval_obj(LPX *lp)
 void spx_eval_col(LPX *lp, int j, double col[], int save)
 {     int m = lp->m;
       int n = lp->n;
-      int *aa_ptr = lp->aa_ptr;
-      int *aa_len = lp->aa_len;
-      int *sv_ndx = lp->sv_ndx;
-      double *sv_val = lp->sv_val;
+      int *aa_ptr = lp->A->ptr;
+      int *aa_len = lp->A->len;
+      int *sv_ndx = lp->A->ndx;
+      double *sv_val = lp->A->val;
       int *indx = lp->indx;
       int i, j_beg, j_end, j_ptr, k;
       double *rhs = col;
@@ -386,10 +387,10 @@ void spx_eval_rho(LPX *lp, int i, double rho[])
 void spx_eval_row(LPX *lp, double rho[], double row[])
 {     int m = lp->m;
       int n = lp->n;
-      int *aa_ptr = lp->aa_ptr;
-      int *aa_len = lp->aa_len;
-      int *sv_ndx = lp->sv_ndx;
-      double *sv_val = lp->sv_val;
+      int *aa_ptr = lp->A->ptr;
+      int *aa_len = lp->A->len;
+      int *sv_ndx = lp->A->ndx;
+      double *sv_val = lp->A->val;
       int *posx = lp->posx;
       int i, i_beg, i_end, i_ptr, j;
       double rho_i;
@@ -558,10 +559,10 @@ int spx_prim_chuzc(SPX *spx, double tol)
       int n = lp->n;
       double dir = (lp->dir == LPX_MIN ? +1.0 : -1.0);
       double *coef = lp->coef;
-      int *aa_ptr = lp->aa_ptr;
-      int *aa_len = lp->aa_len;
-      int *sv_ndx = lp->sv_ndx;
-      double *sv_val = lp->sv_val;
+      int *aa_ptr = lp->A->ptr;
+      int *aa_len = lp->A->len;
+      int *sv_ndx = lp->A->ndx;
+      double *sv_val = lp->A->val;
       int *tagx = lp->tagx;
       int *indx = lp->indx;
       double *pi = lp->pi;
@@ -1024,6 +1025,7 @@ int spx_dual_chuzc(SPX *spx, double relax)
          switch (tagx[k])
          {  case LPX_NF:
                /* xN[j] is free variable */
+               if (abs_ap_j < eps) continue;
                temp = relax / abs_ap_j;
                break;
             case LPX_NL:
@@ -1079,6 +1081,7 @@ int spx_dual_chuzc(SPX *spx, double relax)
          switch (tagx[k])
          {  case LPX_NF:
                /* xN[j] is free variable */
+               if (abs_ap_j < eps) continue;
                temp = 0.0;
                break;
             case LPX_NL:
@@ -1120,18 +1123,22 @@ done: /* restore original signs of the coefficients ap[j] */
 -- *Synopsis*
 --
 -- #include "glpspx.h"
--- void spx_update_bbar(SPX *spx);
+-- void spx_update_bbar(SPX *spx, double *obj);
 --
 -- *Description*
 --
 -- The routine spx_update_bbar recomputes values of basic variables for
 -- an adjacent basis.
 --
+-- If the parameter obj is not NULL, it is assumed that *obj is the
+-- current value of the objective function, in which case the routine
+-- recomputes it for the adjacent basis.
+--
 -- This routine assumes that the basic variable xB[p] and the non-basic
 -- variable xN[q] (that define the adjacent basis) have been chosen but
 -- the current basis has not been changed yet. */
 
-void spx_update_bbar(SPX *spx)
+void spx_update_bbar(SPX *spx, double *obj)
 {     LPX *lp = spx->lp;
       int m = lp->m;
       int n = lp->n;
@@ -1188,7 +1195,8 @@ void spx_update_bbar(SPX *spx)
             default:
                insist(p_tag != p_tag);
          }
-         /* determine decrement of xN[q] in the adjacent basis */
+         /* determine increment of xN[q] in the adjacent basis */
+         insist(aq[p] != 0.0);
          dxn_q = (new_xb_p - bbar[p]) / aq[p];
          /* compute a new value of xN[q] when it has entered the basis
             and taken the place of xB[p] */
@@ -1200,6 +1208,8 @@ void spx_update_bbar(SPX *spx)
             if (aq_i != 0.0) bbar[i] += aq_i * dxn_q;
          }
       }
+      /* recompute value of the objective function (if req'd) */
+      if (obj != NULL) *obj += lp->cbar[q] * dxn_q;
       return;
 }
 
@@ -1235,6 +1245,7 @@ void spx_update_pi(SPX *spx)
       /* xB[p] will leave and xN[q] will enter the basis */
       insist(1 <= p && p <= m);
       insist(1 <= q && q <= n);
+      insist(ap[q] != 0.0);
       new_cbar_q = cbar[q] / ap[q];
       for (i = 1; i <= m; i++)
       {  zeta_i = zeta[i];
@@ -1371,7 +1382,8 @@ int spx_change_basis(SPX *spx)
          /* update the factorization of the basis matrix */
          ret = spx_update(lp, p);
       }
-      /* the basis has been changed; increase iteration count */
+      /* one simplex iteration has been performed */
+      if (lp->it_lim > 0) lp->it_lim--;
       lp->it_cnt++;
       /* return to the simplex method program */
       return ret;
@@ -1539,8 +1551,9 @@ void spx_reset_refsp(SPX *spx)
          default:
             insist(spx->meth != spx->meth);
       }
-      /* remember when the reference space should be reset again */
-      spx->reset = lp->it_cnt + 1000;
+      /* after this number of simplex iterations the reference space
+         should be again reset */
+      spx->count = 1000;
       return;
 }
 
@@ -1565,10 +1578,10 @@ void spx_update_gvec(SPX *spx)
 {     LPX *lp = spx->lp;
       int m = lp->m;
       int n = lp->n;
-      int *aa_ptr = lp->aa_ptr;
-      int *aa_len = lp->aa_len;
-      int *sv_ndx = lp->sv_ndx;
-      double *sv_val = lp->sv_val;
+      int *aa_ptr = lp->A->ptr;
+      int *aa_len = lp->A->len;
+      int *sv_ndx = lp->A->ndx;
+      double *sv_val = lp->A->val;
       int *tagx = lp->tagx;
       int *indx = lp->indx;
       int p = spx->p;
@@ -1583,11 +1596,15 @@ void spx_update_gvec(SPX *spx)
       insist(1 <= p && p <= m);
       insist(1 <= q && q <= n);
       /* check if it's time to reset the reference space */
-      if (lp->it_cnt >= spx->reset)
+      if (spx->count <= 0)
       {  /* yes, do that */
          spx_reset_refsp(spx);
          goto done;
       }
+      else
+      {  /* otherwise decrease the count */
+         spx->count--;
+      }
       /* compute t1 and w */
       t1 = 0.0;
       for (i = 1; i <= m; i++)
@@ -1603,6 +1620,7 @@ void spx_update_gvec(SPX *spx)
       ref_p = refsp[indx[p]];    /* if xB[p] belongs to the space */
       ref_q = refsp[indx[m+q]];  /* if xN[q] belongs to the space */
       ap_q = ap[q];
+      insist(ap_q != 0.0);
       for (j = 1; j <= n; j++)
       {  /* gvec[q] will be computed later */
          if (j == q) continue;
@@ -1735,10 +1753,10 @@ void spx_update_dvec(SPX *spx)
       int m = lp->m;
       int n = lp->n;
       int *typx = lp->typx;
-      int *aa_ptr = lp->aa_ptr;
-      int *aa_len = lp->aa_len;
-      int *sv_ndx = lp->sv_ndx;
-      double *sv_val = lp->sv_val;
+      int *aa_ptr = lp->A->ptr;
+      int *aa_len = lp->A->len;
+      int *sv_ndx = lp->A->ndx;
+      double *sv_val = lp->A->val;
       int *indx = lp->indx;
       int p = spx->p;
       int q = spx->q;
@@ -1752,11 +1770,15 @@ void spx_update_dvec(SPX *spx)
       insist(1 <= p && p <= m);
       insist(1 <= q && q <= n);
       /* check if it's time to reset the reference space */
-      if (lp->it_cnt >= spx->reset)
+      if (spx->count <= 0)
       {  /* yes, do that */
          spx_reset_refsp(spx);
          goto done;
       }
+      else
+      {  /* otherwise decrease the count */
+         spx->count--;
+      }
       /* compute t1 */
       t1 = 0.0;
       for (j = 1; j <= n; j++)
@@ -1790,6 +1812,7 @@ void spx_update_dvec(SPX *spx)
       ref_p = refsp[indx[p]];    /* if xB[p] belongs to the space */
       ref_q = refsp[indx[m+q]];  /* if xN[q] belongs to the space */
       aq_p = aq[p];
+      insist(aq_p != 0.0);
       for (i = 1; i <= m; i++)
       {  /* dvec[p] will be computed later */
          if (i == p) continue;
